==> jc-1.4.0.tar.gz: soot/shimple/internal/SPatchingChain__24SPatchingIterator.h <==
// public class soot.shimple.internal.SPatchingChain$SPatchingIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e23193c43f62eec3 soot_PatchingChain__24PatchingIterator
// @dep_class 71a67834505cd4ed soot_shimple_internal_SPatchingChain__24SPatchingIterator

// header file dependencies
// @dep_header soot_PatchingChain__24PatchingIterator

#include "soot/PatchingChain__24PatchingIterator.h"

#ifndef _JC_soot_shimple_internal_SPatchingChain__24SPatchingIterator_H_
#define _JC_soot_shimple_internal_SPatchingChain__24SPatchingIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_shimple_internal_SPatchingChain$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object;

typedef const struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods;
typedef const struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable;
typedef const struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype;

// Constructors
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$_init$c361f5654126f560(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *, struct _jc_soot_shimple_internal_SPatchingChain$object *, struct _jc_object *);
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$_init$a2a78cbf3a5a7571(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *, struct _jc_soot_shimple_internal_SPatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$_init$bdcf38e05287aa92(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *, struct _jc_soot_shimple_internal_SPatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods {
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *);
};

// Vtable
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_PatchingChain__24PatchingIterator$vmethods	soot_PatchingChain__24PatchingIterator;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods	soot_shimple_internal_SPatchingChain__24SPatchingIterator;
};

// Vtype
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs {
	struct _jc_soot_shimple_internal_SPatchingChain$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs {
    _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs	soot_shimple_internal_SPatchingChain__24SPatchingIterator;
    _jc_soot_PatchingChain__24PatchingIterator$sub_refs	soot_PatchingChain__24PatchingIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs	soot_PatchingChain__24PatchingIterator;
    _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs	soot_shimple_internal_SPatchingChain__24SPatchingIterator;
};

// Object instance structure
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object {
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype	*vtype;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_SPatchingChain__24SPatchingIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$class_object;

#endif	/* _JC_soot_shimple_internal_SPatchingChain__24SPatchingIterator_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/SPatchingChain__24SPatchingIterator.h <==
// public class soot.shimple.internal.SPatchingChain$SPatchingIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e23193c43f62eec3 soot_PatchingChain__24PatchingIterator
// @dep_class 71a67834505cd4ed soot_shimple_internal_SPatchingChain__24SPatchingIterator

// header file dependencies
// @dep_header soot_PatchingChain__24PatchingIterator

#include "soot/PatchingChain__24PatchingIterator.h"

#ifndef _JC_soot_shimple_internal_SPatchingChain__24SPatchingIterator_H_
#define _JC_soot_shimple_internal_SPatchingChain__24SPatchingIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_shimple_internal_SPatchingChain$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs;
typedef struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object;

typedef const struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods;
typedef const struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable;
typedef const struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype;

// Constructors
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$_init$c361f5654126f560(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *, struct _jc_soot_shimple_internal_SPatchingChain$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$_init$a2a78cbf3a5a7571(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *, struct _jc_soot_shimple_internal_SPatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$_init$bdcf38e05287aa92(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *, struct _jc_soot_shimple_internal_SPatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods {
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_PatchingChain__24PatchingIterator$vmethods	soot_PatchingChain__24PatchingIterator;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vmethods	soot_shimple_internal_SPatchingChain__24SPatchingIterator;
};

// Vtype
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs {
	struct _jc_soot_shimple_internal_SPatchingChain$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs {
    _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_refs	soot_shimple_internal_SPatchingChain__24SPatchingIterator;
    _jc_soot_PatchingChain__24PatchingIterator$sub_refs	soot_PatchingChain__24PatchingIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs	soot_PatchingChain__24PatchingIterator;
    _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$sub_nonrefs	soot_shimple_internal_SPatchingChain__24SPatchingIterator;
};

// Object instance structure
struct _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$object {
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype	*vtype;
	_jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$vtype _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_SPatchingChain__24SPatchingIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_SPatchingChain__24SPatchingIterator$class_object;

#endif	/* _JC_soot_shimple_internal_SPatchingChain__24SPatchingIterator_H_ */
